@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -226,6 +226,33 @@ class IndexServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates an Index.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_create_index():
+                # Create a client
+                client = aiplatform_v1.IndexServiceAsyncClient()
+
+                # Initialize request argument(s)
+                index = aiplatform_v1.Index()
+                index.display_name = "display_name_value"
+
+                request = aiplatform_v1.CreateIndexRequest(
+                    parent="parent_value",
+                    index=index,
+                )
+
+                # Make the request
+                operation = client.create_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateIndexRequest, dict]):
                 The request object. Request message for
@@ -292,7 +319,12 @@ class IndexServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -316,6 +348,25 @@ class IndexServiceAsyncClient:
     ) -> index.Index:
         r"""Gets an Index.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_get_index():
+                # Create a client
+                client = aiplatform_v1.IndexServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetIndexRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_index(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetIndexRequest, dict]):
                 The request object. Request message for
@@ -373,7 +424,12 @@ class IndexServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -389,6 +445,26 @@ class IndexServiceAsyncClient:
     ) -> pagers.ListIndexesAsyncPager:
         r"""Lists Indexes in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_list_indexes():
+                # Create a client
+                client = aiplatform_v1.IndexServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListIndexesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_indexes(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListIndexesRequest, dict]):
                 The request object. Request message for
@@ -448,12 +524,20 @@ class IndexServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIndexesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -471,6 +555,32 @@ class IndexServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates an Index.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_update_index():
+                # Create a client
+                client = aiplatform_v1.IndexServiceAsyncClient()
+
+                # Initialize request argument(s)
+                index = aiplatform_v1.Index()
+                index.display_name = "display_name_value"
+
+                request = aiplatform_v1.UpdateIndexRequest(
+                    index=index,
+                )
+
+                # Make the request
+                operation = client.update_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UpdateIndexRequest, dict]):
                 The request object. Request message for
@@ -541,7 +651,12 @@ class IndexServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -567,6 +682,29 @@ class IndexServiceAsyncClient:
         [DeployedIndexes][google.cloud.aiplatform.v1.Index.deployed_indexes]
         had been undeployed.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_delete_index():
+                # Create a client
+                client = aiplatform_v1.IndexServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteIndexRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteIndexRequest, dict]):
                 The request object. Request message for
@@ -636,7 +774,12 @@ class IndexServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
